@@ -12,7 +12,7 @@ use File::Path qw(make_path);
 use Moo;
 use App::Sqitch::Types qw(Sqitch Target);
 
-our $VERSION = 'v1.3.1'; # VERSION
+our $VERSION = 'v1.4.0'; # VERSION
 
 use constant ENGINES => qw(
     pg
@@ -23,6 +23,7 @@ use constant ENGINES => qw(
     vertica
     exasol
     snowflake
+    cockroach
 );
 
 has sqitch => (
@@ -369,6 +370,8 @@ Returns the list of supported engines, currently:
 
 =item * C<snowflake>
 
+=item * C<cockroach>
+
 =back
 
 =head2 Class Methods
@@ -768,7 +771,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2022 iovation Inc., David E. Wheeler
+Copyright (c) 2012-2023 iovation Inc., David E. Wheeler
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
