@@ -15,7 +15,7 @@ use namespace::autoclean;
 extends 'App::Sqitch::Command';
 with 'App::Sqitch::Role::RevertDeployCommand';
 
-our $VERSION = 'v1.3.1'; # VERSION
+our $VERSION = 'v1.4.0'; # VERSION
 
 has onto_change => (
     is  => 'ro',
@@ -78,15 +78,15 @@ sub execute {
 
     # Now get to work.
     $engine->with_verify( $self->verify );
-    $engine->no_prompt( $self->no_prompt );
-    $engine->prompt_accept( $self->prompt_accept );
     $engine->log_only( $self->log_only );
     $engine->lock_timeout( $self->lock_timeout );
 
     # Revert.
     $engine->set_variables( $self->_collect_revert_vars($target) );
+    die unless defined $self->no_prompt;
+    die unless defined $self->prompt_accept;
     try {
-        $engine->revert( $onto );
+        $engine->revert( $onto, ! ($self->no_prompt), $self->prompt_accept );
     } catch {
         # Rethrow unknown errors or errors with exitval > 1.
         die $_ if ! eval { $_->isa('App::Sqitch::X') }
@@ -175,7 +175,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2022 iovation Inc., David E. Wheeler
+Copyright (c) 2012-2023 iovation Inc., David E. Wheeler
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
