@@ -14,7 +14,7 @@ use namespace::autoclean;
 extends 'App::Sqitch::Command';
 with 'App::Sqitch::Role::ContextCommand';
 
-our $VERSION = 'v1.3.1'; # VERSION
+our $VERSION = 'v1.4.0'; # VERSION
 
 has change_name => (
     is  => 'ro',
@@ -203,6 +203,9 @@ sub _copy {
         return;
     }
 
+    # Create the directory for the file, if it does not exist.
+    $self->_mkpath($dest->dir->stringify);
+
     # Stringify to work around bug in File::Copy warning on 5.10.0.
     File::Copy::syscopy "$src", "$dest" or hurl rework => __x(
         'Cannot copy {src} to {dest}: {error}',
@@ -310,7 +313,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2022 iovation Inc., David E. Wheeler
+Copyright (c) 2012-2023 iovation Inc., David E. Wheeler
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
