@@ -15,7 +15,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = 'v1.3.1'; # VERSION
+our $VERSION = 'v1.4.0'; # VERSION
 
 sub _dt($) {
     require App::Sqitch::DateTime;
@@ -146,11 +146,8 @@ has dbh => (
                     );
                     $dbh->do("ALTER SESSION SET TIME_ZONE='UTC'");
                     if (my $schema = $self->registry) {
-                        try {
-                            $dbh->do("OPEN SCHEMA $schema");
-                            # https://www.nntp.perl.org/group/perl.dbi.dev/2013/11/msg7622.html
-                            $dbh->set_err(undef, undef) if $dbh->err;
-                        };
+                        $dbh->do("OPEN SCHEMA $schema")
+                            or $self->_handle_no_registry($dbh);
                     }
                     return;
                 },
@@ -198,7 +195,7 @@ sub _multi_values {
     return join "\nUNION ALL ", ("SELECT $expr FROM dual") x $count;
 }
 
-sub initialized {
+sub _initialized {
     my $self = shift;
     return $self->dbh->selectcol_arrayref(q{
         SELECT EXISTS(
@@ -320,7 +317,7 @@ sub _registry_variable {
     return "DEFINE registry=$schema;";
 }
 
-sub initialize {
+sub _initialize {
     my $self   = shift;
     my $schema = $self->registry;
     hurl engine => __ 'Sqitch already initialized' if $self->initialized;
@@ -471,6 +468,11 @@ sub _no_column_error  {
     return $DBI::errstr && $DBI::errstr =~ /object \w+ not found/m;
 }
 
+sub _unique_error  {
+    # Unique constraints not supported by Exasol
+    return 0;
+}
+
 sub _script {
     my $self = shift;
     my $uri  = $self->uri;
@@ -570,7 +572,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2022 iovation Inc., David E. Wheeler
+Copyright (c) 2012-2023 iovation Inc., David E. Wheeler
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
